/*
 * Copyright (c) 1997-2017 Oracle and/or its affiliates. All rights reserved.
 */

package	javasoft.sqe.tests.api.javax.activation.FileTypeMap;

import	java.io.*;
import	javax.activation.*;
import	com.sun.javatest.*;
import	javasoft.sqe.tests.api.javax.activation.TestClasses.TestFileTypeMap;

/** FileTypeMap is an abstract class. The main functional testing is in the only provided
 *  concrete implementation, MimetypesFileTypeMap, tested separately.<p>
 *  Get a default FileTypeMap object then use it to call setDefaultFileTypeMap() api
 *  with {FileTypeMap|null} parameter, then call getDefaultFileTypeMap() method, if
 *  set/get values are the same then this testcase passes, otherwise it fails. <p>
 */

public class setDefaultFileTypeMap_Test implements Test
{

public static void main(String argv[])
{
	setDefaultFileTypeMap_Test lTest = new setDefaultFileTypeMap_Test();
	Status lStatus = lTest.run(argv, new PrintWriter(System.err, true), new PrintWriter(System.out, true));
	lStatus.exit();
}

public Status run(String argv[], PrintWriter outLog, PrintWriter outConsole)
{
	// does getDefaultFileTypeMap return a MimetypesFileTypeMap?
	FileTypeMap systemTypeMap = FileTypeMap.getDefaultFileTypeMap();

	if (systemTypeMap == null)
	    return Status.failed("getDefaultFileTypeMap() returned null");
	 
	// Does setDefaultFileTypeMapMap work?   
	FileTypeMap testTypeMap = new TestFileTypeMap();
	FileTypeMap.setDefaultFileTypeMap(testTypeMap); 	// API TEST

	if (!testTypeMap.equals(FileTypeMap.getDefaultFileTypeMap()))
	    return Status.failed("getDefaultFileTypeMap failed to return FileTypeMap provided in setDefaultFileTypeMap");
    
	// Does setDefaultFileTypeMap(null) reset the default?  Note that this will return a new instance
	// of MimetypesFileTypeMap. The original instance was not cached when setDefaultFileTypeMap was called.

	FileTypeMap.setDefaultFileTypeMap(null);	// API TEST
	FileTypeMap restoredSysTypeMap = FileTypeMap.getDefaultFileTypeMap();

	if( restoredSysTypeMap == null)
	    return Status.failed("after setDefaultFileTypeMap(null) getDefaultFileTypeMap() returned null");

	if(!restoredSysTypeMap.getClass().equals(systemTypeMap.getClass()))
	    return Status.failed("setDefaultFileTypeMap(null) didn't reset default to original system map");

	return Status.passed("setDefaultFileTypeMap() test succeeded");
}

}
